@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 
 ###############################################################################
@@ -105,7 +105,7 @@ sub _write_bar_chart {
     my $subtype = $self->{_subtype};
     $subtype = 'percentStacked' if $subtype eq 'percent_stacked';
 
-    $self->{_writer}->startTag( 'c:barChart' );
+    $self->xml_start_tag( 'c:barChart' );
 
     # Write the c:barDir element.
     $self->_write_bar_dir();
@@ -125,7 +125,7 @@ sub _write_bar_chart {
     # Write the c:axId elements
     $self->_write_axis_ids( %args );
 
-    $self->{_writer}->endTag( 'c:barChart' );
+    $self->xml_end_tag( 'c:barChart' );
 }
 
 
@@ -142,7 +142,7 @@ sub _write_bar_dir {
 
     my @attributes = ( 'val' => $val );
 
-    $self->{_writer}->emptyTag( 'c:barDir', @attributes );
+    $self->xml_empty_tag( 'c:barDir', @attributes );
 }
 
 
@@ -170,7 +170,7 @@ sub _write_number_format {
         'sourceLinked' => $source_linked,
     );
 
-    $self->{_writer}->emptyTag( 'c:numFmt', @attributes );
+    $self->xml_empty_tag( 'c:numFmt', @attributes );
 }
 
 
