@@ -21,7 +21,7 @@ use Carp;
 use Excel::Writer::XLSX::Package::XMLwriter;
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 
 ###############################################################################
@@ -62,9 +62,9 @@ our @overrides = (
 sub new {
 
     my $class = shift;
-    my $self  = Excel::Writer::XLSX::Package::XMLwriter->new();
+    my $fh    = shift;
+    my $self  = Excel::Writer::XLSX::Package::XMLwriter->new( $fh );
 
-    $self->{_writer}    = undef;
     $self->{_defaults}  = [@defaults];
     $self->{_overrides} = [@overrides];
 
@@ -84,18 +84,15 @@ sub _assemble_xml_file {
 
     my $self = shift;
 
-    return unless $self->{_writer};
-
-    $self->_write_xml_declaration;
+    $self->xml_declaration;
     $self->_write_types();
     $self->_write_defaults();
     $self->_write_overrides();
 
-    $self->{_writer}->endTag( 'Types' );
+    $self->xml_end_tag( 'Types' );
 
-    # Close the XM writer object and filehandle.
-    $self->{_writer}->end();
-    $self->{_writer}->getOutput()->close();
+    # Close the XML writer filehandle.
+    $self->xml_get_fh()->close();
 }
 
 
@@ -318,7 +315,7 @@ sub _write_defaults {
 
     for my $aref ( @{ $self->{_defaults} } ) {
         #<<<
-        $self->{_writer}->emptyTag(
+        $self->xml_empty_tag(
             'Default',
             'Extension',   $aref->[0],
             'ContentType', $aref->[1] );
@@ -339,7 +336,7 @@ sub _write_overrides {
 
     for my $aref ( @{ $self->{_overrides} } ) {
         #<<<
-        $self->{_writer}->emptyTag(
+        $self->xml_empty_tag(
             'Override',
             'PartName',    $aref->[0],
             'ContentType', $aref->[1] );
@@ -368,7 +365,7 @@ sub _write_types {
 
     my @attributes = ( 'xmlns' => $xmlns, );
 
-    $self->{_writer}->startTag( 'Types', @attributes );
+    $self->xml_start_tag( 'Types', @attributes );
 }
 
 ###############################################################################
@@ -388,7 +385,7 @@ sub _write_default {
         'ContentType' => $content_type,
     );
 
-    $self->{_writer}->emptyTag( 'Default', @attributes );
+    $self->xml_empty_tag( 'Default', @attributes );
 }
 
 
@@ -403,14 +400,14 @@ sub _write_override {
     my $self         = shift;
     my $part_name    = shift;
     my $content_type = shift;
-    my $writer       = $self->{_writer};
+    my $writer       = $self;
 
     my @attributes = (
         'PartName'    => $part_name,
         'ContentType' => $content_type,
     );
 
-    $self->{_writer}->emptyTag( 'Override', @attributes );
+    $self->xml_empty_tag( 'Override', @attributes );
 }
 
 
