@@ -20,7 +20,7 @@ use Carp;
 use Excel::Writer::XLSX::Package::XMLwriter;
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 
 ###############################################################################
@@ -39,9 +39,9 @@ our $VERSION = '0.51';
 sub new {
 
     my $class = shift;
-    my $self  = Excel::Writer::XLSX::Package::XMLwriter->new();
+    my $fh    = shift;
+    my $self  = Excel::Writer::XLSX::Package::XMLwriter->new( $fh );
 
-    $self->{_writer}     = undef;
     $self->{_properties} = {};
 
     bless $self, $class;
@@ -60,9 +60,7 @@ sub _assemble_xml_file {
 
     my $self = shift;
 
-    return unless $self->{_writer};
-
-    $self->_write_xml_declaration;
+    $self->xml_declaration;
 
     # Write the table element.
     $self->_write_table();
@@ -78,11 +76,10 @@ sub _assemble_xml_file {
 
 
     # Close the table tag.
-    $self->{_writer}->endTag( 'table' );
+    $self->xml_end_tag( 'table' );
 
-    # Close the XML writer object and filehandle.
-    $self->{_writer}->end();
-    $self->{_writer}->getOutput()->close();
+    # Close the XML writer filehandle.
+    $self->xml_get_fh()->close();
 }
 
 
@@ -115,23 +112,6 @@ sub _set_properties {
 ###############################################################################
 
 
-###############################################################################
-#
-# _write_xml_declaration()
-#
-# Write the XML declaration.
-#
-sub _write_xml_declaration {
-
-    my $self       = shift;
-    my $writer     = $self->{_writer};
-    my $encoding   = 'UTF-8';
-    my $standalone = 1;
-
-    $writer->xmlDecl( $encoding, $standalone );
-}
-
-
 ##############################################################################
 #
 # _write_table()
@@ -168,7 +148,7 @@ sub _write_table {
     }
 
 
-    $self->{_writer}->startTag( 'table', @attributes );
+    $self->xml_start_tag( 'table', @attributes );
 }
 
 
@@ -187,7 +167,7 @@ sub _write_auto_filter {
 
     my @attributes = ( 'ref' => $autofilter, );
 
-    $self->{_writer}->emptyTag( 'autoFilter', @attributes );
+    $self->xml_empty_tag( 'autoFilter', @attributes );
 }
 
 
@@ -206,7 +186,7 @@ sub _write_table_columns {
 
     my @attributes = ( 'count' => $count, );
 
-    $self->{_writer}->startTag( 'tableColumns', @attributes );
+    $self->xml_start_tag( 'tableColumns', @attributes );
 
     for my $col_data ( @columns ) {
 
@@ -214,7 +194,7 @@ sub _write_table_columns {
         $self->_write_table_column( $col_data );
     }
 
-    $self->{_writer}->endTag( 'tableColumns' );
+    $self->xml_end_tag( 'tableColumns' );
 }
 
 
@@ -248,15 +228,15 @@ sub _write_table_column {
     }
 
     if ( $col_data->{_formula} ) {
-        $self->{_writer}->startTag( 'tableColumn', @attributes );
+        $self->xml_start_tag( 'tableColumn', @attributes );
 
         # Write the calculatedColumnFormula element.
         $self->_write_calculated_column_formula( $col_data->{_formula} );
 
-        $self->{_writer}->endTag( 'tableColumn' );
+        $self->xml_end_tag( 'tableColumn' );
     }
     else {
-        $self->{_writer}->emptyTag( 'tableColumn', @attributes );
+        $self->xml_empty_tag( 'tableColumn', @attributes );
     }
 
 }
@@ -287,7 +267,7 @@ sub _write_table_style_info {
         'showColumnStripes' => $show_column_stripes,
     );
 
-    $self->{_writer}->emptyTag( 'tableStyleInfo', @attributes );
+    $self->xml_empty_tag( 'tableStyleInfo', @attributes );
 }
 
 
@@ -302,7 +282,7 @@ sub _write_calculated_column_formula {
     my $self    = shift;
     my $formula = shift;
 
-    $self->{_writer}->dataElement( 'calculatedColumnFormula', $formula );
+    $self->xml_data_element( 'calculatedColumnFormula', $formula );
 }
 
 
