@@ -20,7 +20,7 @@ use Carp;
 use Excel::Writer::XLSX::Package::XMLwriter;
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 
 ###############################################################################
@@ -39,8 +39,8 @@ our $VERSION = '0.51';
 sub new {
 
     my $class = shift;
-
-    my $self = { _writer => undef, };
+    my $fh    = shift;
+    my $self  = Excel::Writer::XLSX::Package::XMLwriter->new( $fh );
 
     bless $self, $class;
 
@@ -61,8 +61,6 @@ sub _assemble_xml_file {
     my $vml_shape_id  = shift;
     my $comments_data = shift;
 
-    return unless $self->{_writer};
-
     $self->_write_xml_namespace;
 
     # Write the o:shapelayout element.
@@ -78,11 +76,10 @@ sub _assemble_xml_file {
         $self->_write_shape( ++$vml_shape_id, $z_index++, $comment );
     }
 
-    $self->{_writer}->endTag( 'xml' );
+    $self->xml_end_tag( 'xml' );
 
-    # Close the XM writer object and filehandle.
-    $self->{_writer}->end();
-    $self->{_writer}->getOutput()->close();
+    # Close the XML writer filehandle.
+    $self->xml_get_fh()->close();
 }
 
 
@@ -144,7 +141,7 @@ sub _write_xml_namespace {
         'xmlns:x' => $xmlns_x,
     );
 
-    $self->{_writer}->startTag( 'xml', @attributes );
+    $self->xml_start_tag( 'xml', @attributes );
 }
 
 
@@ -162,12 +159,12 @@ sub _write_shapelayout {
 
     my @attributes = ( 'v:ext' => $ext );
 
-    $self->{_writer}->startTag( 'o:shapelayout', @attributes );
+    $self->xml_start_tag( 'o:shapelayout', @attributes );
 
     # Write the o:idmap element.
     $self->_write_idmap( $data_id );
 
-    $self->{_writer}->endTag( 'o:shapelayout' );
+    $self->xml_end_tag( 'o:shapelayout' );
 }
 
 
@@ -188,7 +185,7 @@ sub _write_idmap {
         'data'  => $data_id,
     );
 
-    $self->{_writer}->emptyTag( 'o:idmap', @attributes );
+    $self->xml_empty_tag( 'o:idmap', @attributes );
 }
 
 
@@ -213,7 +210,7 @@ sub _write_shapetype {
         'path'      => $path,
     );
 
-    $self->{_writer}->startTag( 'v:shapetype', @attributes );
+    $self->xml_start_tag( 'v:shapetype', @attributes );
 
     # Write the v:stroke element.
     $self->_write_stroke();
@@ -221,7 +218,7 @@ sub _write_shapetype {
     # Write the v:path element.
     $self->_write_path( 't', 'rect' );
 
-    $self->{_writer}->endTag( 'v:shapetype' );
+    $self->xml_end_tag( 'v:shapetype' );
 }
 
 
@@ -238,7 +235,7 @@ sub _write_stroke {
 
     my @attributes = ( 'joinstyle' => $joinstyle );
 
-    $self->{_writer}->emptyTag( 'v:stroke', @attributes );
+    $self->xml_empty_tag( 'v:stroke', @attributes );
 }
 
 
@@ -258,7 +255,7 @@ sub _write_path {
     push @attributes, ( 'gradientshapeok' => 't' ) if $gradientshapeok;
     push @attributes, ( 'o:connecttype' => $connecttype );
 
-    $self->{_writer}->emptyTag( 'v:path', @attributes );
+    $self->xml_empty_tag( 'v:path', @attributes );
 }
 
 
@@ -319,7 +316,7 @@ sub _write_shape {
         'o:insetmode' => $insetmode,
     );
 
-    $self->{_writer}->startTag( 'v:shape', @attributes );
+    $self->xml_start_tag( 'v:shape', @attributes );
 
     # Write the v:fill element.
     $self->_write_fill();
@@ -336,7 +333,7 @@ sub _write_shape {
     # Write the x:ClientData element.
     $self->_write_client_data( $row, $col, $visible, $vertices );
 
-    $self->{_writer}->endTag( 'v:shape' );
+    $self->xml_end_tag( 'v:shape' );
 }
 
 
@@ -353,7 +350,7 @@ sub _write_fill {
 
     my @attributes = ( 'color2' => $color_2 );
 
-    $self->{_writer}->emptyTag( 'v:fill', @attributes );
+    $self->xml_empty_tag( 'v:fill', @attributes );
 }
 
 
@@ -376,7 +373,7 @@ sub _write_shadow {
         'obscured' => $obscured,
     );
 
-    $self->{_writer}->emptyTag( 'v:shadow', @attributes );
+    $self->xml_empty_tag( 'v:shadow', @attributes );
 }
 
 
@@ -393,12 +390,12 @@ sub _write_textbox {
 
     my @attributes = ( 'style' => $style );
 
-    $self->{_writer}->startTag( 'v:textbox', @attributes );
+    $self->xml_start_tag( 'v:textbox', @attributes );
 
     # Write the div element.
     $self->_write_div();
 
-    $self->{_writer}->endTag( 'v:textbox' );
+    $self->xml_end_tag( 'v:textbox' );
 }
 
 
@@ -415,10 +412,10 @@ sub _write_div {
 
     my @attributes = ( 'style' => $style );
 
-    $self->{_writer}->startTag( 'div', @attributes );
+    $self->xml_start_tag( 'div', @attributes );
 
 
-    $self->{_writer}->endTag( 'div' );
+    $self->xml_end_tag( 'div' );
 }
 
 
@@ -439,7 +436,7 @@ sub _write_client_data {
 
     my @attributes = ( 'ObjectType' => $object_type );
 
-    $self->{_writer}->startTag( 'x:ClientData', @attributes );
+    $self->xml_start_tag( 'x:ClientData', @attributes );
 
     # Write the x:MoveWithCells element.
     $self->_write_move_with_cells();
@@ -462,7 +459,7 @@ sub _write_client_data {
     # Write the x:Visible element.
     $self->_write_visible() if $visible;
 
-    $self->{_writer}->endTag( 'x:ClientData' );
+    $self->xml_end_tag( 'x:ClientData' );
 }
 
 
@@ -476,7 +473,7 @@ sub _write_move_with_cells {
 
     my $self = shift;
 
-    $self->{_writer}->emptyTag( 'x:MoveWithCells' );
+    $self->xml_empty_tag( 'x:MoveWithCells' );
 }
 
 
@@ -490,7 +487,7 @@ sub _write_size_with_cells {
 
     my $self = shift;
 
-    $self->{_writer}->emptyTag( 'x:SizeWithCells' );
+    $self->xml_empty_tag( 'x:SizeWithCells' );
 }
 
 
@@ -504,7 +501,7 @@ sub _write_visible {
 
     my $self = shift;
 
-    $self->{_writer}->emptyTag( 'x:Visible' );
+    $self->xml_empty_tag( 'x:Visible' );
 }
 
 
@@ -525,7 +522,7 @@ sub _write_anchor {
     my $data = join ", ",
       ( $col_start, $x1, $row_start, $y1, $col_end, $x2, $row_end, $y2 );
 
-    $self->{_writer}->dataElement( 'x:Anchor', $data );
+    $self->xml_data_element( 'x:Anchor', $data );
 }
 
 
@@ -540,7 +537,7 @@ sub _write_auto_fill {
     my $self = shift;
     my $data = 'False';
 
-    $self->{_writer}->dataElement( 'x:AutoFill', $data );
+    $self->xml_data_element( 'x:AutoFill', $data );
 }
 
 
@@ -555,7 +552,7 @@ sub _write_row {
     my $self = shift;
     my $data = shift;
 
-    $self->{_writer}->dataElement( 'x:Row', $data );
+    $self->xml_data_element( 'x:Row', $data );
 }
 
 
@@ -570,7 +567,7 @@ sub _write_column {
     my $self = shift;
     my $data = shift;
 
-    $self->{_writer}->dataElement( 'x:Column', $data );
+    $self->xml_data_element( 'x:Column', $data );
 }
 
 
