@@ -20,7 +20,7 @@ use Carp;
 use Exporter;
 
 our @ISA     = qw(Exporter);
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 our $AUTOLOAD;
 
 ###############################################################################
@@ -30,8 +30,10 @@ our $AUTOLOAD;
 sub new {
 
     my $class      = shift;
+    my $fh         = shift;
+    my $self       = Excel::Writer::XLSX::Package::XMLwriter->new( $fh );
+
     my %properties = @_;
-    my $self       = Excel::Writer::XLSX::Package::XMLwriter->new();
 
     $self->{_name} = undef;
     $self->{_type} = 'rect';
@@ -307,13 +309,14 @@ To create a simple Excel file containing shapes using L<Excel::Writer::XLSX>:
         text => "Hello\nWorld"
     );
 
-    # Add a cross shape.
-    my $cross = $workbook->add_shape( type => 'cross');
+    # Add a plus shape.
+    my $plus = $workbook->add_shape( type => 'plus');
 
     # Insert the shapes in the worksheet.
-    $worksheet->insert_shape( 'A1', $rect );
-    $worksheet->insert_shape( 'B2', $ellipse );
-    $worksheet->insert_shape( 'C3', $cross );
+    $worksheet->insert_shape( 'B3', $rect );
+    $worksheet->insert_shape( 'C3', $ellipse );
+    $worksheet->insert_shape( 'D3', $plus );
+
 
 =head1 DESCRIPTION
 
